@@ -59,8 +59,7 @@ public enum TemplateErrorMessage implements OXErrorMessage {
     IOException(Category.SUBSYSTEM_OR_SERVICE_DOWN, 1, "Verify file system and templates.", "An IOException occurred."),
     UnderlyingException(Category.CODE_ERROR, 2, "Please correct the template", "The underlying templating system threw an exception: %s"),
     TemplateNotFound(Category.CODE_ERROR, 3, "Please use an existing template", "The template %s does not exist."),
-    SQLException(Category.CODE_ERROR, 4, "An underlying system threw an SQLException", "Please try again later."),
-    AccessDenied(Category.PERMISSION, 5, "File access is denied due to operating system's permissions.", "File access denied."),
+    SQLException(Category.CODE_ERROR, 4, "An underlying system threw an SQLException", "Please try again later.")
     ;
 
     private Category category;
