@@ -49,8 +49,7 @@
 
 package com.openexchange.templating;
 
-import static com.openexchange.templating.TemplateErrorMessage.IOException;
-import static com.openexchange.templating.TemplateErrorMessage.TemplateNotFound;
+import static com.openexchange.templating.TemplateErrorMessage.*;
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileFilter;
@@ -67,9 +66,9 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Properties;
 import java.util.Set;
+import java.util.Map.Entry;
 import java.util.concurrent.ConcurrentHashMap;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -79,11 +78,11 @@ import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.session.Session;
 import com.openexchange.templating.base.OXTemplate;
-import com.openexchange.templating.base.OXTemplate.TemplateLevel;
 import com.openexchange.templating.base.OXTemplateExceptionHandler;
 import com.openexchange.templating.base.TemplateException;
 import com.openexchange.templating.base.TemplateService;
 import com.openexchange.templating.base.TemplatingHelper;
+import com.openexchange.templating.base.OXTemplate.TemplateLevel;
 import com.openexchange.templating.impl.OXFolderHelper;
 import com.openexchange.templating.impl.OXInfostoreHelper;
 import com.openexchange.templating.impl.TemplatingHelperImpl;
@@ -108,190 +107,70 @@ public class TemplateServiceImpl implements TemplateService {
 
     private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(TemplateServiceImpl.class));
 
-    private final Object lock;
-    private final ConfigurationService config;
+    private ConfigurationService config;
+
     private OXFolderHelper folders;
+
     private OXInfostoreHelper infostore;
+
     private TemplateExceptionHandler exceptionHandler;
-    private final String defaultTemplatePath;
 
     public TemplateServiceImpl(ConfigurationService config) {
-        lock = new Object();
         this.config = config;
         exceptionHandler = null;
-        defaultTemplatePath = config.getProperty(PATH_PROPERTY);
-    }
-
-    private void checkTemplatePath(final String templatePath) throws TemplateException {
-        try {
-            if (isEmpty(templatePath)) {
-                return;
-            }
-            final String defaultTemplatePath = this.defaultTemplatePath;
-            if (defaultTemplatePath == null) {
-                return;
-            }
-            if (toLowerCase(defaultTemplatePath).equals(toLowerCase(templatePath))) {
-                // Equal directory
-                return;
-            }
-            if (isSubDirectory(new File(defaultTemplatePath), new File(templatePath))) {
-                return;
-            }
-            // A file is accessed in a foreign directory
-            final TemplateException e = TemplateErrorMessage.AccessDenied.create();
-            LOG.error(new StringBuilder(64).append(e.getErrorCode()).append(": Acces to file denied: \"").append(templatePath).append("\" exceptionID=").append(e.getExceptionID()).toString());
-            throw e;
-        } catch (final IOException e) {
-            throw TemplateErrorMessage.IOException.create(e, e.getMessage());
-        }
-    }
-
-    /**
-     * Checks, whether the child directory is a sub-directory of the base directory.
-     *
-     * @param base The base directory.
-     * @param child The suspected child directory.
-     * @return <code>true</code> if the child is a sub-directory of the base directory.
-     * @throws IOException If an I/O error occurred during the test.
-     */
-    private boolean isSubDirectory(final File base, final File child) throws IOException {
-        final File b = base.getCanonicalFile();
-        final File c = child.getCanonicalFile();
-
-        File parentFile = c;
-        while (parentFile != null) {
-            if (b.equals(parentFile)) {
-                return true;
-            }
-            parentFile = parentFile.getParentFile();
-        }
-        return false;
     }
 
     public OXTemplateImpl loadTemplate(String templateName) throws TemplateException {
-        final String templatePath = defaultTemplatePath;
+        String templatePath = config.getProperty(PATH_PROPERTY);
         if (templatePath == null) {
             return null;
         }
 
-        final OXTemplateImpl retval = new OXTemplateImpl();
+        OXTemplateImpl retval = new OXTemplateImpl();
         retval.setLevel(TemplateLevel.SERVER);
         retval.setTemplate(loadTemplate(templatePath, templateName));
         return retval;
+
     }
 
     protected Template loadTemplate(String templatePath, String templateName) throws TemplateException {
-        final File path = new File(templatePath);
+        File path = new File(templatePath);
         if (!path.exists() || !path.isDirectory() || !path.canRead()) {
             return null;
         }
-        checkTemplatePath(templatePath);
 
-        synchronized (lock) {
-            Template retval = null;
-            try {
-                final TemplateLoader templateLoader = new FileTemplateLoader(path);
-                final String userDir = System.getProperty("user.dir");
-                System.setProperty("user.dir", templatePath);
-                final Configuration config = new Configuration();
-                System.setProperty("user.dir", userDir);
-                config.setTemplateLoader(templateLoader);
-                if (exceptionHandler != null) {
-                    config.setTemplateExceptionHandler(exceptionHandler);
-                }
-                retval = config.getTemplate(templateName);
-            } catch (final IOException e) {
-                throw IOException.create(e);
+        Template retval = null;
+        try {
+            TemplateLoader templateLoader = new FileTemplateLoader(path);
+            Configuration config = new Configuration();
+            config.setTemplateLoader(templateLoader);
+            if (exceptionHandler != null) {
+                config.setTemplateExceptionHandler(exceptionHandler);
             }
-            if (retval == null) {
-                throw TemplateNotFound.create(templateName);
-            }
-            return retval;
+            retval = config.getTemplate(templateName);
+        } catch (FileNotFoundException e) {
+            throw TemplateNotFound.create(templateName);
+        } catch (IOException e) {
+            throw IOException.create(e);
         }
+        if (retval == null) {
+            throw TemplateNotFound.create(templateName);
+        }
+        return retval;
     }
 
     public OXTemplate loadTemplate(String templateName, String defaultTemplateName, Session baseSession) throws TemplateException {
         return loadTemplate(templateName, defaultTemplateName, baseSession, true);
     }
 
-    public OXTemplate loadTemplate(String templateName, String defaultTemplateName, Session baseSession, boolean create) throws TemplateException {
-        ServerSession session;
-        try {
-            session = ServerSessionAdapter.valueOf(baseSession);
-        } catch (ContextException e1) {
-            throw new TemplateException(e1);
-        }
-        if (isEmpty(templateName) || !isUserTemplatingEnabled(session)) {
-            return loadTemplate(defaultTemplateName);
-        }
-        synchronized (lock) {
-            try {
-                FolderObject folder = folders.getPrivateTemplateFolder(session);
-                FolderObject privateFolder = folder;
-                boolean global = false;
-
-                if (null == folder) {
-                    folder = folders.getGlobalTemplateFolder(session);
-                    global = true;
-                }
-                String templateText = (folder == null) ? null : infostore.findTemplateInFolder(session, folder, templateName);
-
-                final String userDir = System.getProperty("user.dir");
-                final String templatePath = config.getProperty(PATH_PROPERTY);
-                System.setProperty("user.dir", templatePath);
-                final Configuration config = new Configuration();
-                System.setProperty("user.dir", userDir);
-                if (exceptionHandler != null) {
-                    config.setTemplateExceptionHandler(exceptionHandler);
-                }
-                if (templateText != null) {
-                    final OXTemplateImpl template = new OXTemplateImpl();
-                    template.setTemplate(new Template(templateName, new StringReader(templateText), config));
-                    template.setLevel(TemplateLevel.USER);
-                    return template;
-                }
-
-                if (!global) {
-                    folder = folders.getGlobalTemplateFolder(session);
-                    global = true;
-
-                    templateText = (folder == null) ? null : infostore.findTemplateInFolder(session, folder, templateName);
-                }
-
-                if (templateText == null) {
-
-                    if (existsInFilesystem(templateName)) {
-                        templateText = loadFromFileSystem(templateName);
-                        final OXTemplateImpl template = new OXTemplateImpl();
-                        template.setTemplate(new Template(templateName, new StringReader(templateText), config));
-                        template.setLevel(TemplateLevel.SERVER);
-                        return template;
-                    }
-
-                    templateText = loadFromFileSystem(defaultTemplateName);
-                    if (privateFolder == null) {
-                        folder = folders.createPrivateTemplateFolder(session);
-                        privateFolder = folder;
-                    }
-                    infostore.storeTemplateInFolder(session, privateFolder, templateName, templateText);
-                }
-                final OXTemplateImpl template = new OXTemplateImpl();
-                template.setTemplate(new Template(templateName, new StringReader(templateText), config));
-                template.setLevel(TemplateLevel.USER);
-                return template;
-            } catch (AbstractOXException e) {
-                throw new TemplateException(e);
-            } catch (final IOException e) {
-                throw IOException.create(e);
-            }
-        }
-    }
-
     private boolean isUserTemplatingEnabled(ServerSession session) {
         return "true".equalsIgnoreCase(config.getProperty(USER_TEMPLATING_PROPERTY, "true")) && session.getUserConfiguration().hasInfostore();
     }
 
+    private boolean isEmpty(String templateName) {
+        return templateName == null || "".equals(templateName);
+    }
+
     protected boolean existsInFilesystem(String templateName) {
         File templateFile = getTemplateFile(templateName);
         if (!templateFile.exists() || !templateFile.exists() || !templateFile.canRead()) {
@@ -305,7 +184,6 @@ public class TemplateServiceImpl implements TemplateService {
         if (!templateFile.exists() || !templateFile.exists() || !templateFile.canRead()) {
         	throw TemplateErrorMessage.TemplateNotFound.create(defaultTemplateName);
         }
-        checkTemplatePath(templateFile.getPath());
         BufferedReader reader = null;
         try {
             StringBuilder builder = new StringBuilder();
@@ -329,19 +207,19 @@ public class TemplateServiceImpl implements TemplateService {
     }
 
     private File getTemplateFile(String defaultTemplateName) {
-        return new File(defaultTemplatePath, defaultTemplateName);
+        return new File(config.getProperty(PATH_PROPERTY), defaultTemplateName);
     }
 
-    public synchronized void setOXFolderHelper(OXFolderHelper helper) {
+    public void setOXFolderHelper(OXFolderHelper helper) {
         this.folders = helper;
     }
 
-    public synchronized void setInfostoreHelper(OXInfostoreHelper helper) {
+    public void setInfostoreHelper(OXInfostoreHelper helper) {
         this.infostore = helper;
     }
 
     public List<String> getBasicTemplateNames(String... filter) {
-        String templatePath = defaultTemplatePath;
+        String templatePath = config.getProperty(PATH_PROPERTY);
         File templateDir = new File(templatePath);
         if (!templateDir.isDirectory() || !templateDir.exists()) {
             return new ArrayList<String>(0);
@@ -487,26 +365,77 @@ public class TemplateServiceImpl implements TemplateService {
         return new TemplatingHelperImpl(rootObject, session, this, createCopy);
     }
 
-    private boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
+    public OXTemplate loadTemplate(String templateName, String defaultTemplateName, Session baseSession, boolean create) throws TemplateException {
+        ServerSession session;
+        try {
+            session = ServerSessionAdapter.valueOf(baseSession);
+        } catch (ContextException e1) {
+            throw new TemplateException(e1);
         }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = Character.isWhitespace(string.charAt(i));
+        if (isEmpty(templateName) || !isUserTemplatingEnabled(session)) {
+            return loadTemplate(defaultTemplateName);
         }
-        return isWhitespace;
-    }
+        try {
+            FolderObject folder = folders.getPrivateTemplateFolder(session);
+            FolderObject privateFolder = folder;
+            boolean global = false;
 
-    private String toLowerCase(final CharSequence chars) {
-        final int length = chars.length();
-        final StringBuilder builder = new StringBuilder(length);
-        for (int i = 0; i < length; i++) {
-            final char c = chars.charAt(i);
-            builder.append((c >= 'A') && (c <= 'Z') ? (char) (c ^ 0x20) : c);
+            if (null == folder) {
+                folder = folders.getGlobalTemplateFolder(session);
+                global = true;
+            }
+            String templateText = (folder == null) ? null : infostore.findTemplateInFolder(session, folder, templateName);
+
+            String userDir = System.getProperty("user.dir");
+            String templatePath = config.getProperty(PATH_PROPERTY);
+            System.setProperty("user.dir", templatePath);
+            Configuration config = new Configuration();
+            System.setProperty("user.dir", userDir);
+            if (exceptionHandler != null) {
+                config.setTemplateExceptionHandler(exceptionHandler);
+            }
+            if (templateText != null) {
+                OXTemplateImpl template = new OXTemplateImpl();
+                template.setTemplate(new Template(templateName, new StringReader(templateText), config));
+                template.setLevel(TemplateLevel.USER);
+                return template;
+            }
+
+            if (!global) {
+                folder = folders.getGlobalTemplateFolder(session);
+                global = true;
+
+                templateText = (folder == null) ? null : infostore.findTemplateInFolder(session, folder, templateName);
+            }
+
+            if (templateText == null) {
+
+                if (existsInFilesystem(templateName)) {
+                    templateText = loadFromFileSystem(templateName);
+                    OXTemplateImpl template = new OXTemplateImpl();
+                    template.setTemplate(new Template(templateName, new StringReader(templateText), config));
+                    template.setLevel(TemplateLevel.SERVER);
+                    return template;
+                }
+
+                templateText = loadFromFileSystem(defaultTemplateName);
+                if (create) {
+                    if (privateFolder == null) {
+                        folder = folders.createPrivateTemplateFolder(session);
+                        privateFolder = folder;
+                    }
+                    infostore.storeTemplateInFolder(session, privateFolder, templateName, templateText);
+                }
+            }
+            OXTemplateImpl template = new OXTemplateImpl();
+            template.setTemplate(new Template(templateName, new StringReader(templateText), config));
+            template.setLevel(TemplateLevel.USER);
+            return template;
+        } catch (AbstractOXException e) {
+            throw new TemplateException(e);
+        } catch (IOException e) {
+            throw IOException.create(e);
         }
-        return builder.toString();
     }
 
 }
