@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,7 @@ package com.openexchange.templating.impl;
 
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
-import com.openexchange.tools.session.ServerSession;
+import com.openexchange.session.Session;
 
 
 /**
@@ -61,7 +61,7 @@ import com.openexchange.tools.session.ServerSession;
  *
  */
 public interface OXFolderHelper {
-    public FolderObject getPrivateTemplateFolder(ServerSession session) throws AbstractOXException;
-    public FolderObject getGlobalTemplateFolder(ServerSession session) throws AbstractOXException;
-    public FolderObject createPrivateTemplateFolder(ServerSession session) throws AbstractOXException;
+    public FolderObject getPrivateTemplateFolder(Session session) throws AbstractOXException;
+    public FolderObject getGlobalTemplateFolder(Session session) throws AbstractOXException;
+    public FolderObject createPrivateTemplateFolder(Session session) throws AbstractOXException;
 }
