@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,8 +58,8 @@ import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.server.osgiservice.ServiceDependentRegistration;
 import com.openexchange.server.osgiservice.Whiteboard;
 import com.openexchange.templating.TemplateErrorMessage;
-import com.openexchange.templating.TemplateService;
 import com.openexchange.templating.TemplateServiceImpl;
+import com.openexchange.templating.base.TemplateService;
 import com.openexchange.templating.impl.OXIntegration;
 
 /**
@@ -93,7 +93,10 @@ public class Activator implements BundleActivator {
             public boolean validateServices() {
                 boolean hasProperty = config.getProperty(TemplateServiceImpl.PATH_PROPERTY) != null;
                 if(!hasProperty) {
-                    LOG.warn(TemplateServiceImpl.PATH_PROPERTY+" is not set. Templating will remain inactive.");
+                    IllegalStateException exception = new IllegalStateException("Missing Property "+TemplateServiceImpl.PATH_PROPERTY);
+                    exception.fillInStackTrace();
+                    
+                    LOG.error(TemplateServiceImpl.PATH_PROPERTY+" is not set. Templating will remain inactive.",exception);
                 }
                 return hasProperty;
             }
